@@ -1,5 +1,11 @@
 context("sf classes")
 
+un_class <- function(x) {
+  x = unclass(x)
+  attributes(x) = NULL
+  return(x)
+}
+
 if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
 
   #suppressPackageStartupMessages(library(sf))
@@ -50,13 +56,13 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     pt_sfc_json <- geojson_json(pt_sfc)
     pt_sf_json <- geojson_json(pt_sf)
 
-    expect_equal(unclass(pt_sfg_json),
+    expect_equal(un_class(pt_sfg_json),
                  "{\"type\":\"Point\",\"coordinates\":[3.2,4]}")
 
-    expect_equal(unclass(pt_sfc_json),
+    expect_equal(un_class(pt_sfc_json),
                  "{\"type\":\"GeometryCollection\",\"geometries\":[{\"type\":\"Point\",\"coordinates\":[3.2,4]},{\"type\":\"Point\",\"coordinates\":[3,4.6]},{\"type\":\"Point\",\"coordinates\":[3.8,4.4]}]}")
 
-    expect_equal(unclass(pt_sf_json),
+    expect_equal(un_class(pt_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"Point\",\"coordinates\":[3.2,4]}},{\"type\":\"Feature\",\"properties\":{\"x\":\"b\"},\"geometry\":{\"type\":\"Point\",\"coordinates\":[3,4.6]}},{\"type\":\"Feature\",\"properties\":{\"x\":\"c\"},\"geometry\":{\"type\":\"Point\",\"coordinates\":[3.8,4.4]}}]}")
   })
 
@@ -81,17 +87,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     mp_sfc_json <- geojson_json(mp_sfc)
     mp_sf_json <-  geojson_json(mp_sf)
 
-    expect_s3_class(mp_sfg_json, "geo_json")
-    expect_s3_class(mp_sfc_json, "geo_json")
-    expect_s3_class(mp_sf_json, "geo_json")
+    expect_s3_class(mp_sfg_json, "geojson")
+    expect_s3_class(mp_sfc_json, "geojson")
+    expect_s3_class(mp_sf_json, "geojson")
 
-    expect_equal(unclass(mp_sfg_json),
+    expect_equal(un_class(mp_sfg_json),
                  "{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]}")
 
-    expect_equal(unclass(mp_sfc_json),
+    expect_equal(un_class(mp_sfc_json),
                  "{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]}")
 
-    expect_equal(unclass(mp_sf_json),
+    expect_equal(un_class(mp_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]}}]}")
   })
 
@@ -117,17 +123,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     pol_sfc_json <- geojson_json(pol_sfc)
     pol_sf_json <-  geojson_json(pol_sf)
 
-    expect_s3_class(pol_sfg_json, "geo_json")
-    expect_s3_class(pol_sfc_json, "geo_json")
-    expect_s3_class(pol_sf_json, "geo_json")
+    expect_s3_class(pol_sfg_json, "geojson")
+    expect_s3_class(pol_sfc_json, "geojson")
+    expect_s3_class(pol_sf_json, "geojson")
 
-    expect_equal(unclass(pol_sfg_json),
+    expect_equal(un_class(pol_sfg_json),
                  "{\"type\":\"Polygon\",\"coordinates\":[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]]}")
 
-    expect_equal(unclass(pol_sfc_json),
+    expect_equal(un_class(pol_sfc_json),
                  "{\"type\":\"Polygon\",\"coordinates\":[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]]}")
 
-    expect_equal(unclass(pol_sf_json),
+    expect_equal(un_class(pol_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"Polygon\",\"coordinates\":[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]]}}]}")
   })
 
@@ -154,17 +160,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     mpol_sfc_json <- geojson_json(mpol_sfc)
     mpol_sf_json <- geojson_json(mpol_sf)
 
-    expect_s3_class(mpol_sfg_json, "geo_json")
-    expect_s3_class(mpol_sfc_json, "geo_json")
-    expect_s3_class(mpol_sf_json, "geo_json")
+    expect_s3_class(mpol_sfg_json, "geojson")
+    expect_s3_class(mpol_sfc_json, "geojson")
+    expect_s3_class(mpol_sf_json, "geojson")
 
-    expect_equal(unclass(mpol_sfg_json),
+    expect_equal(un_class(mpol_sfg_json),
                  "{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]}")
 
-    expect_equal(unclass(mpol_sfc_json),
+    expect_equal(un_class(mpol_sfc_json),
                  "{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]}")
 
-    expect_equal(unclass(mpol_sf_json),
+    expect_equal(un_class(mpol_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]}}]}")
   })
 
@@ -192,17 +198,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     ls_sfc_json <- geojson_json(ls_sfc)
     ls_sf_json <- geojson_json(ls_sf)
 
-    expect_s3_class(ls_sfg_json, "geo_json")
-    expect_s3_class(ls_sfc_json, "geo_json")
-    expect_s3_class(ls_sf_json, "geo_json")
+    expect_s3_class(ls_sfg_json, "geojson")
+    expect_s3_class(ls_sfc_json, "geojson")
+    expect_s3_class(ls_sf_json, "geojson")
 
-    expect_equal(unclass(ls_sfg_json),
+    expect_equal(un_class(ls_sfg_json),
                  "{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}")
 
-    expect_equal(unclass(ls_sfc_json),
+    expect_equal(un_class(ls_sfc_json),
                  "{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}")
 
-    expect_equal(unclass(ls_sf_json),
+    expect_equal(un_class(ls_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}}]}")
   })
 
@@ -229,17 +235,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     mls_sfc_json <- geojson_json(mls_sfc)
     mls_sf_json <- geojson_json(mls_sf)
 
-    expect_s3_class(mls_sfg_json, "geo_json")
-    expect_s3_class(mls_sfc_json, "geo_json")
-    expect_s3_class(mls_sf_json, "geo_json")
+    expect_s3_class(mls_sfg_json, "geojson")
+    expect_s3_class(mls_sfc_json, "geojson")
+    expect_s3_class(mls_sf_json, "geojson")
 
-    expect_equal(unclass(mls_sfg_json),
+    expect_equal(un_class(mls_sfg_json),
                  "{\"type\":\"MultiLineString\",\"coordinates\":[[[0,3],[0,4],[1,5],[2,5]],[[0.2,3],[0.2,4],[1,4.8],[2,4.8]],[[0,4.4],[0.6,5]]]}")
 
-    expect_equal(unclass(mls_sfc_json),
+    expect_equal(un_class(mls_sfc_json),
                  "{\"type\":\"MultiLineString\",\"coordinates\":[[[0,3],[0,4],[1,5],[2,5]],[[0.2,3],[0.2,4],[1,4.8],[2,4.8]],[[0,4.4],[0.6,5]]]}")
 
-    expect_equal(unclass(mls_sf_json),
+    expect_equal(un_class(mls_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"MultiLineString\",\"coordinates\":[[[0,3],[0,4],[1,5],[2,5]],[[0.2,3],[0.2,4],[1,4.8],[2,4.8]],[[0,4.4],[0.6,5]]]}}]}")
   })
 
@@ -264,17 +270,17 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
     gc_sfc_json <- geojson_json(gc_sfc)
     gc_sf_json <- geojson_json(gc_sf)
 
-    expect_s3_class(gc_sfg_json, "geo_json")
-    expect_s3_class(gc_sfc_json, "geo_json")
-    expect_s3_class(gc_sf_json, "geo_json")
+    expect_s3_class(gc_sfg_json, "geojson")
+    expect_s3_class(gc_sfc_json, "geojson")
+    expect_s3_class(gc_sf_json, "geojson")
 
-    expect_equal(unclass(gc_sfg_json),
+    expect_equal(un_class(gc_sfg_json),
                  "{\"type\":\"GeometryCollection\",\"geometries\":[{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]},{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]},{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}]}")
 
-    expect_equal(unclass(gc_sfc_json),
+    expect_equal(un_class(gc_sfc_json),
                  "{\"type\":\"GeometryCollection\",\"geometries\":[{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]},{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]},{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}]}")
 
-    expect_equal(unclass(gc_sf_json),
+    expect_equal(un_class(gc_sf_json),
                  "{\"type\":\"FeatureCollection\",\"features\":[{\"type\":\"Feature\",\"properties\":{\"x\":\"a\"},\"geometry\":{\"type\":\"GeometryCollection\",\"geometries\":[{\"type\":\"MultiPoint\",\"coordinates\":[[3.2,4],[3,4.6],[3.8,4.4],[3.5,3.8],[3.4,3.6],[3.9,4.5]]},{\"type\":\"MultiPolygon\",\"coordinates\":[[[[0,0],[1,0],[3,2],[2,4],[1,4],[0,0]],[[1,1],[1,2],[2,2],[1,1]]],[[[3,0],[4,0],[4,1],[3,1],[3,0]],[[3.3,0.3],[3.3,0.8],[3.8,0.8],[3.8,0.3],[3.3,0.3]]],[[[3,3],[4,2],[4,3],[3,3]]]]},{\"type\":\"LineString\",\"coordinates\":[[0,3],[0,4],[1,5],[2,5]]}]}}]}")
   })
 
@@ -291,10 +297,6 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
                           st_point, dim = "XYZM")
     pt_sfc_xyzm <- st_sfc(p_list_xyzm)
     pt_sf_xyzm <- st_sf(x = c("a", "b", "c"), pt_sfc_xyzm)
-
-
-
-    expect_equal
   })
 
   test_that("Deal with M dimensions: multipoint", {
@@ -311,7 +313,7 @@ if (suppressPackageStartupMessages(require("sf", quietly = TRUE))) {
   test_that("sf columns of class units are processed as numeric", {
     pol_sf$area <- structure(rep(1, nrow(pol_sf)), class = "units")
     
-    expect_s3_class(geojson_json(pol_sf), "geo_json")
+    expect_s3_class(geojson_json(pol_sf), "geojson")
     expect_equal(read_sf(geojson_json(pol_sf))[["area"]], as.numeric(pol_sf$area))
   })
 
